@@ -1346,19 +1346,34 @@ None
         value = value[0]
 
         if value is not None:
-            value = Data.asdata(abs(value*1.0))
+#            value = Data.asdata(abs(value*1.0))
+            value = Data.asdata(value)
             units = value.Units
             if not units:
                 value = value.override_units(self.Units)
-            elif not units.equivalent(self.Units):
-                raise ValueError(
-"Period units {0!r} are not equivalent to coordinate units {1!r}".format(
+            elif units != self.Units:
+                if units.equivalent(self.Units):
+                    value.Units = self.Units
+                else:
+                    raise ValueError(
+"Period units {!r} are not equivalent to coordinate units {!r}".format(
     units, self.Units))
+            #--- End: if
 
-            range = self.Data.range()
-            if range >= value:
+            value = abs(value)
+            value.dtype = float
+            
+            if self.isdimension:
+                # Faster than `range`
+                array = self.array
+#                r =  abs(self.datum(-1) - self.datum(0))
+                r =  abs(array[-1] - array[0])
+            else:
+                r = self.Data.range().datum(0)
+
+            if r >= value.datum(0):
                 raise ValueError(
-"The coordinate range {0!r} is not less than the period {1!r}".format(
+"The coordinate range {!r} is not less than the period {!r}".format(
     range, value))
         #--- End: if
 
