@@ -34,7 +34,16 @@ from numpy.ma import where        as numpy_ma_where
 from ..functions import broadcast_array
 
 def asanyarray(*args):
-    '''
+    '''asdasd
+
+:Parameters:
+
+    args: sequence of `numpy.ndarray`
+
+:Returns:
+
+    out: `tuple`
+
     '''
     out = []
     for x in args:
@@ -350,6 +359,12 @@ def min_fpartial(out, out1=None):
     return asanyarray(N, amin)
 #--- End: def
 
+#def min_f_new(outs):
+#    for out in outs:
+#        new = min_fpartial(out)
+#
+#    return new
+
 def min_ffinalise(out, sub_samples=None):
     '''
     sub_samples : *optional*
@@ -392,7 +407,7 @@ The weighted average along the specified axes.
         average = numpy_ma_average
     else:
         average = numpy_average
-
+    
     avg, sw = average(a, axis=axis, weights=weights, returned=True)
         
     if not numpy_ndim(avg):
@@ -404,28 +419,43 @@ The weighted average along the specified axes.
     else:
         N = sample_size_f(a, axis=axis, masked=masked)
         
-#    (N, avg, sw) = asanyarray(N, avg, sw)
-
     return asanyarray(N, avg, sw)
 #--- End: def
 
 def mean_fpartial(out, out1=None):
-    '''
+    '''Return the partial sample size,the partial sum and partial sum of
+the weights.
+
+:Parameters:
+
+    out: 3-`tuple` of `numpy.ndarray`
+        Either an output from a previous call to `mean_fpartial`; or,
+        if *out1* is `None`, an output from `mean_f`.
+
+    out1: 3-`tuple` of `numpy.ndarray`, optional
+        An output from `mean_f`.
+        
 :Returns:
 
-    out: `numpy.ndarray`, `numpy.ndarray`, `numpy.ndarray`
-'''
+    out: 3-`tuple` of `numpy.ndarray`
+
+    '''
     N, avg, sw = out
     
     if out1 is None:
+        # This is the first partition to be processed
+
+        # Convert the partition average to a partition sum
         avg *= sw
     else:
+        # Combine this partition with existing parital combination
         N1, avg1, sw1 = out1
 
+        # Convert the partition average to a partition sum
         avg1 *= sw1
         
         N   = psum(N, N1)
-        avg = psum(avg, avg1)
+        avg = psum(avg, avg1) # Now a partial sum
         sw  = psum(sw, sw1)
     #--- End: if
 
@@ -433,14 +463,21 @@ def mean_fpartial(out, out1=None):
 #--- End: def
 
 def mean_ffinalise(out, sub_samples=None):
-    '''
+    '''Divide the weighted sum by the sum of weights.
+
+Also mask out any values derived from a too-small sample size.
+
+:Parameters:
+
+    out: 3-`tuple` of `numpy.ndarray`
+        An output from `mean_fpartial`. 
 
     sub_samples: optional
-        Ignored.
 
 :Returns:
 
-    out: `numpy.ndarray`, `numpy.ndarray`
+    out: 2-`tuple` of `numpy.ndarray`
+        The sample size and the mean.
 
 '''
     N, avg, sw = out
@@ -701,6 +738,7 @@ def sw_f(a, axis=None, masked=False, weights=None, N=None,
         N = sample_size_f(a, axis=axis, masked=masked)
 
     if weights is not None:
+        # A weights array has been provided
         weights = double_precision(weights)
 
         if weights.ndim < a.ndim:
@@ -717,6 +755,8 @@ def sw_f(a, axis=None, masked=False, weights=None, N=None,
         if not numpy_ndim(sw):
             sw = numpy_asanyarray(sw)
     else:
+        # The sum of weights is equal to the sample size (i.e. an
+        # unweighted sample)
         sw = N.copy()
 
     return asanyarray(N, sw)
@@ -738,6 +778,24 @@ sw2_ffinalise = sum_ffinalise
 def var_f(a, axis=None, weights=None, masked=False, ddof=0):
     '''
 
+========  ============================================================
+Variable  Description
+========  ============================================================
+N         Sample size
+
+var       Sample variance (ddof=0)
+
+avg       Weighted mean
+
+V1        Sum of weights
+
+V2        Sum of squares of weights
+
+ddof      Delta degrees of freedom
+
+weighted  Whether or not the sample is weighted
+========  ============================================================
+
 :Return:
     out: `tuple`
 
@@ -799,13 +857,40 @@ def var_f(a, axis=None, weights=None, masked=False, ddof=0):
 #--- End: def
 
 def var_fpartial(out, out1=None):
-    '''https://en.wikipedia.org/wiki/Pooled_variance#Population-based_statistics
+    '''Return:
+
+* The partial sum sample sizes
+
+* Partial sum of V1*(variance + mean^2)
+
+* Unweighted partial sum
+
+========  ============================================================
+Variable  Description
+========  ============================================================
+N         Partial sample size
+
+var       Partial sum of V1*(variance + mean^2)
+
+avg       Unweighted partial sum
+
+V1        Partial sum of weights
+
+V2        Partial sum of squares of weights
+
+ddof      Delta degrees of freedom
+
+weighted  Whether or not the population is weighted
+========  ============================================================
+
+
+https://en.wikipedia.org/wiki/Pooled_variance#Population-based_statistics
 
 :Parameters:
 
-    out: `tuple`
+    out: 7-`tuple`
 
-    out1: `tuple`, optional
+    out1: 7-`tuple`, optional
 
 :Returns:
 
@@ -815,15 +900,15 @@ def var_fpartial(out, out1=None):
     if out1 is None:
         # ------------------------------------------------------------
         # var = V1(var+avg**2)
-        # avg = V1*avg
+        # avg = V1*avg = unweighted partial sum
         # ------------------------------------------------------------
         var += avg*avg
         var *= V1
         avg *= V1
     else:       
         # ------------------------------------------------------------
-        # var = var + V11(var1+avg1**2)
-        # avg = avg + V11*avg1
+        # var = var + V1b(varb+avgb**2)
+        # avg = avg + V1b*avgb
         # V1  = V1 + V1b
         # V2  = V2 + V2b
         # ------------------------------------------------------------
