@@ -1550,6 +1550,11 @@ class DataTest(unittest.TestCase):
             f = cf.read(self.filename6)[0]
             self.assertTrue(list(sorted(f.Data.section((1,2)).keys()))
                             == [(x, None, None) for x in range(1800)])
+            d = cf.Data(numpy.arange(120).reshape(2, 3, 4, 5))
+            x = d.section([1, 3])
+            self.assertTrue(len(x) == 8)
+            e = cf.Data.reconstruct_sectioned_data(x)
+            self.assertTrue(e.equals(d))
         #--- End: for
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
